==> mule-profiling-api-1.0.0-sources.jar: org/mule/runtime/api/profiling/ProfilingService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.runtime.api.profiling;

import org.mule.api.annotation.Experimental;
import org.mule.api.annotation.NoImplement;
import org.mule.runtime.api.profiling.threading.ThreadSnapshotCollector;
import org.mule.runtime.api.profiling.type.ProfilingEventType;

/**
 * Service that provides profiling resources. This is implemented by the Runtime. Different components can inject this service and
 * register or obtain a {@link ProfilingDataProducer} to begin emitting profiling data. For instance:
 *
 * <code>
 *    &#64;Inject
 *    private ProfilingService profilingService;
 *
 *     // register a profiling data producer for the TEST_PROFILING_TYPE event type
 *     profilingService.register(TEST_PROFILING_TYPE, new TestProfilingDataProducer());
 *
 *     // ....
 *
 *     // trigger a profiling event
 *     profilingService.getProfilingDataProducer(TEST_PROFILING_TYPE).event(data);
 * </code>
 *
 * @see ProfilingDataProducer
 * @see ProfilingEventType
 * @since 1.0
 */
@Experimental
@NoImplement
public interface ProfilingService {

  /**
   * Returns a previously registered {@link ProfilingDataProducer} that can be used to emit profiling events of a certain
   * {@link ProfilingEventType}.
   *
   * @param profilingEventType the {@link ProfilingEventType} that will be emitted.
   * @return the corresponding {@link ProfilingDataProducer}
   */
  <T extends ProfilingEventContext> ProfilingDataProducer<T> getProfilingDataProducer(ProfilingEventType<T> profilingEventType);

  /**
   * Registers a {@link ProfilingDataProducer} that can be obtained to emit profiling events of a certain
   * {@link ProfilingEventType}.
   *
   * @param profilingEventType    the {@link ProfilingEventType} that the {@link ProfilingDataProducer} will emit.
   * @param profilingDataProducer the {@link ProfilingDataProducer} that will be registered.
   */
  <T extends ProfilingEventContext> void registerProfilingDataProducer(ProfilingEventType<T> profilingEventType,
                                                                       ProfilingDataProducer<T> profilingDataProducer);

  /**
   * Returns a {@link ThreadSnapshotCollector} that can be used to collect information about threading.
   *
   * @return the {@link ThreadSnapshotCollector}.
   */
  ThreadSnapshotCollector getThreadSnapshotCollector();

}

==> mule-profiling-api-1.0.0-20221024-sources.jar: org/mule/runtime/api/profiling/ProfilingService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.runtime.api.profiling;

import org.mule.api.annotation.Experimental;
import org.mule.api.annotation.NoImplement;
import org.mule.runtime.api.profiling.threading.ThreadSnapshotCollector;
import org.mule.runtime.api.profiling.type.ProfilingEventType;

/**
 * Service that provides profiling resources. This is implemented by the Runtime. Different components can inject this service and
 * register or obtain a {@link ProfilingDataProducer} to begin emitting profiling data. For instance:
 *
 * <code>
 *    &#64;Inject
 *    private ProfilingService profilingService;
 *
 *     // register a profiling data producer for the TEST_PROFILING_TYPE event type
 *     profilingService.register(TEST_PROFILING_TYPE, new TestProfilingDataProducer());
 *
 *     // ....
 *
 *     // trigger a profiling event
 *     profilingService.getProfilingDataProducer(TEST_PROFILING_TYPE).event(data);
 * </code>
 *
 * @see ProfilingDataProducer
 * @see ProfilingEventType
 * @since 1.0
 */
@Experimental
@NoImplement
public interface ProfilingService {

  /**
   * Returns a previously registered {@link ProfilingDataProducer} that can be used to emit profiling events of a certain
   * {@link ProfilingEventType}.
   *
   * @param profilingEventType the {@link ProfilingEventType} that will be emitted.
   * @return the corresponding {@link ProfilingDataProducer}
   */
  <T extends ProfilingEventContext, S> ProfilingDataProducer<T, S> getProfilingDataProducer(ProfilingEventType<T> profilingEventType);

  /**
   * Returns a previously registered {@link ProfilingDataProducer} that can be used to emit profiling events of a certain
   * {@link ProfilingEventType} indicating the producer scope.
   *
   * @param profilingEventType the {@link ProfilingEventType} that the {@link ProfilingDataProducer} will emit
   * @param producerScope      the {@link ProfilingProducerScope} that will be bound to the the {@link ProfilingDataProducer}
   *
   * @return the corresponding {@link ProfilingDataProducer}
   */
  <T extends ProfilingEventContext, S> ProfilingDataProducer<T, S> getProfilingDataProducer(ProfilingEventType<T> profilingEventType,
                                                                                            ProfilingProducerScope producerScope);

  /**
   * Registers a {@link ProfilingDataProducer} that can be obtained to emit profiling events of a certain
   * {@link ProfilingEventType}.
   *
   * @param profilingEventType    the {@link ProfilingEventType} that the {@link ProfilingDataProducer} will emit.
   * @param profilingDataProducer the {@link ProfilingDataProducer} that will be registered.
   */
  <T extends ProfilingEventContext, S> void registerProfilingDataProducer(ProfilingEventType<T> profilingEventType,
                                                                          ProfilingDataProducer<T, S> profilingDataProducer);

  /**
   * Returns a {@link ThreadSnapshotCollector} that can be used to collect information about threading.
   *
   * @return the {@link ThreadSnapshotCollector}.
   */
  ThreadSnapshotCollector getThreadSnapshotCollector();

}
